
# Changes

## Version 1.5.0 (2020-05-04)

We closed a total of 9 issues (enhancements and bug fixes) through 3 pull requests, since our last release on 2020-05-03.

## Highlights
 * New logo!
 * Minimum/maximum spanning trees
 * Refactored *K* Function
 * More notebooks and tutorials
 * Further improved and refactored testing

## Issues Closed
  - GHA for release and publish (#487)
  - Attempting GHA release workflow #2 (#489)
  - Attempting GHA release workflow (#488)
  - Version bump for release v1.5.0.rc0 (#486)
  - [WIP] Update Network K Function (#469)
  - Break spatial analysis tutorial into several notebooks (#478)

## Pull Requests
  - Attempting GHA release workflow #2 (#489)
  - Attempting GHA release workflow (#488)
  - Version bump for release v1.5.0.rc0 (#486)

The following individuals contributed to this release:

  - James Gaboardi

------------------------------------

## Version 1.5.0.rc0 (2020-05-02)

We closed a total of 100 issues (enhancements and bug fixes) through 38 pull requests, since our last release on 2020-02-24.

## Issues Closed
  - [WIP] Update Network K Function (#469)
  - Break spatial analysis tutorial into several notebooks (#478)
  - Update, review, and rename K statistic (#477)
  -  toy PR to test codecov.yml (#485)
  - toy PR to test tcodecov.yml (#484)
  - treebeard CI (#481)
  - Docs funding (#483)
  - [WIP] Dropping "change" param in codecov.yml (#479)
  - Add funding source? (#480)
  - add funding sources to README (#482)
  - [BUG] Correction to NetworkK formulation (#470)
  - Revert "[Bug] Addressing bug in K-Function formation" (#476)
  - [Bug] Addressing bug in K-Function formation (#471)
  - [TST] add codecov.yml (#472)
  - no post until 24 codecov reports (#475)
  - attempting custom codecov reports (#474)
  - update install docs (#473)
  - Network L Function (#467)
  - Remove G and F functions (#466)
  - Removing G and F functions (#468)
  - [TEST] regular 3x3 lattice for network analysis testing (#442)
  - DOC: correct comments for K-function related code (#465)
  - Updating docs with new sphinx release (#464)
  - Remedy for non-transparent favicon (#463)
  - stylize the minimum spanning tree plot in README.md (#462)
  - Updating pinned requirements versions (#461)
  - Streamling GHA (#460)
  - [ENH] Functionality for spanning trees (#449)
  - [ENH][WIP] Min/Max Spanning Trees functionality (#459)
  - Update Python version support in CONTRIBUTING.md (#458)
  - Adding network arc spatial weights notebook (#457)
  - Appveyor still being triggered (#454)
  - Corrections for Caveat notebook (#456)
  - CHANGELOG.txt --> CHANGELOG.md (#455)
  - [TST] GitHub Actions only; Migrate away from Travis/Appveyor (#453)
  - Customizing/improving GitHub Actions (#452)
  - Trying out GitHub Actions for additional testing (#451)
  - [ENH] caveats notebook (#426)
  - [WIP][ENH] New notebook for caveats (#445)
  - release v1.4.3 (#404)
  - logo update, rearrange (#448)
  - updating README logo (#447)
  - package import warning? (#427)
  - Improved docstrings for NetworkF and NetworkG (#444)
  - analysis.ffunction() may not be correct (#225)
  - [MAINT] re-evaluate testing structure (#438)
  - [TST] Updating tests and testing structure (#443)
  - moving watermark to notebook reqs (#441)
  - appveyor — rebuild the master 3.8 PYPI (#436)
  - [MAINT] DRYing off unittests (#439)
  - Docs for v1.4.2.post1 were not rebuilt (#434)
  - rebuilding docs for post release (#435)
  - release v1.4.2 (#392)
  - pushing changelog for 1.4.2post1 (#433)
  - version bump v1.4.2 --> 1.4.2post1 (#432)
  - fixing conda-forge failure (#431)
  - final PR before v1.4.2 release — updating CHANGELOG.md (#430)
  - updating README (#429)
  - [WIP][ENH] longest and largest network components (#424)
  - Add a fully connected attribute (#425)
  - [ENH] longest/largest connected component (#414)
  - add logos to website (#345)

## Pull Requests
  - Update, review, and rename K statistic (#477)
  -  toy PR to test codecov.yml (#485)
  - Docs funding (#483)
  - [WIP] Dropping "change" param in codecov.yml (#479)
  - add funding sources to README (#482)
  - [Bug] Addressing bug in K-Function formation (#471)
  - no post until 24 codecov reports (#475)
  - attempting custom codecov reports (#474)
  - update install docs (#473)
  - Removing G and F functions (#468)
  - DOC: correct comments for K-function related code (#465)
  - Updating docs with new sphinx release (#464)
  - Remedy for non-transparent favicon (#463)
  - stylize the minimum spanning tree plot in README.md (#462)
  - Updating pinned requirements versions (#461)
  - Streamling GHA (#460)
  - [ENH][WIP] Min/Max Spanning Trees functionality (#459)
  - Update Python version support in CONTRIBUTING.md (#458)
  - Adding network arc spatial weights notebook (#457)
  - Corrections for Caveat notebook (#456)
  - CHANGELOG.txt --> CHANGELOG.md (#455)
  - [TST] GitHub Actions only; Migrate away from Travis/Appveyor (#453)
  - Customizing/improving GitHub Actions (#452)
  - Trying out GitHub Actions for additional testing (#451)
  - [WIP][ENH] New notebook for caveats (#445)
  - logo update, rearrange (#448)
  - updating README logo (#447)
  - Improved docstrings for NetworkF and NetworkG (#444)
  - [TST] Updating tests and testing structure (#443)
  - moving watermark to notebook reqs (#441)
  - [MAINT] DRYing off unittests (#439)
  - rebuilding docs for post release (#435)
  - pushing changelog for 1.4.2post1 (#433)
  - version bump v1.4.2 --> 1.4.2post1 (#432)
  - fixing conda-forge failure (#431)
  - final PR before v1.4.2 release — updating CHANGELOG.md (#430)
  - updating README (#429)
  - [WIP][ENH] longest and largest network components (#424)

The following individuals contributed to this release:

  - James Gaboardi
  - Serge Rey

------------------------------------


## Version 1.4.2.post2 (2020-02-24)

We closed a total of 1 issues (enhancements and bug fixes) through 1 pull requests, since our last release on 2020-02-24.

## Issues Closed
 - rebuilding docs for post release (#435)

## Pull Requests
  - Docs for v1.4.2.post1 were not rebuilt (#434)

The following individuals contributed to this release:

  - James Gaboardi

------------------------------------


## Version 1.4.2post1 (2020-02-24)

We closed a total of 0 issues (enhancements and bug fixes) through 2 pull requests, since our last release on 2020-02-24.

## Pull Requests
  - version bump v1.4.2 --> 1.4.2post1 (#432)
  - fixing conda-forge failure (#431)

The following individuals contributed to this release:

  - James Gaboardi

------------------------------------


## Version 1.4.2 (2020-02-24)

We closed a total of 57 issues (enhancements and bug fixes) through 18 pull requests, since our last release on 2020-01-25.

## Highlights
 * Python 3.8 support and Windows OS testing
 * Increased robustness of `regular_lattices()`, which now can create a lattice from any bounds, including bounding box of a shapefile or GeoDataFrame
 * Point type A to point type B shortest path extraction
 * Longest and largest network component identification
 * Network component extraction
 * New "Integrations and Applications" notebook
 * General cleanup, including bug and typo fixes


## Issues Closed
  - updating README (#429)
  - [WIP][ENH] longest and largest network components (#424)
  - Add a fully connected attribute (#425)
  - [ENH] longest/largest connected component (#414)
  - add logos to website (#345)
  - attempting fast finish again (#428)
  - pushing fix for environment.yml (#423)
  - Add 3.8 as a supported Python version in docs (#422)
  - [ENH] matplotlib-scalebar for notebooks/binders (#416)
  - using a true scalebar in notebook plots (#421)
  - [REQ] requirements for notebooks/binders? (#413)
  - adding notebook reqs files (#420)
  - support multiplatform testing (#407)
  - make sure data set is downloaded for appveyor.yml (#419)
  - Migrate testing functionality from nose to pytest (#417)
  - [ENH] moving towards multi-platform testing (#418)
  - [On Hold] too many emails from Travis CI (#322)
  - origin-destination point patterns for shortest_paths() (#412)
  - The Transportation Problem notebook (#103)
  - transportation problem ipynb and type-a to type-b shortest paths (#415)
  - [WIP][ENH] origin for lattice (#405)
  - add testing for Python 3.8 (#408)
  - [BUG] typo in Travis CI badge URL (#410)
  - silently hands RuntimeWarning in NetworkK (#411)
  - adding py3.8 to travis (#409)
  - [DOC] notebook doc pngs (#406)
  - release v1.4.1 (#365)
  - rebuilding docs for version bump (#402)
  - Version bump to v1.4.1 (#401)
  - Binder is broken for network-analysis (#399)
  - Some tutorial links giving 404 (#400)
  - Fix links 2 (#398)
  - Fix links for notebooks (#397)
  - [DOC] Reorg for tutorials page (#396)
  - Traveling Salesperson Notebook (#110)
  - create new TSP notebook with pulp (#100)
  - [WIP] TSP notebook (#386)
  - [DOC] paths docstring missing (#394)
  - correcting routes doc (#395)

## Pull Requests
  - final PR before v1.4.2 release — updating CHANGELOG.md (#430)
  - updating README (#429)
  - [WIP][ENH] longest and largest network components (#424)
  - pushing fix for environment.yml (#423)
  - Add 3.8 as a supported Python version in docs (#422)
  - using a true scalebar in notebook plots (#421)
  - adding notebook reqs files (#420)
  - make sure data set is downloaded for appveyor.yml (#419)
  - [ENH] moving towards multi-platform testing (#418)
  - transportation problem ipynb and type-a to type-b shortest paths (#415)
  - [WIP][ENH] origin for lattice (#405)
  - adding py3.8 to travis (#409)
  - [DOC] notebook doc pngs (#406)
  - rebuilding docs for version bump (#402)
  - Version bump to v1.4.1 (#401)
  - Fix links 2 (#398)
  - Fix links for notebooks (#397)
  - [WIP] TSP notebook (#386)
  - correcting routes doc (#395)

The following individuals contributed to this release:

  - James Gaboardi
  - Serge Rey



---------------------------------------------

## Version 1.4.1 (2020-01-25)

We closed a total of 93 issues (enhancements and bug fixes) through 35 pull requests, since our last release on 2019-12-31.

## Issues Closed
  - Binder is broken for network-analysis (#399)
  - Some tutorial links giving 404 (#400)
  - Fix links 2 (#398)
  - Fix links for notebooks (#397)
  - [DOC] Reorg for tutorials page (#396)
  - Traveling Salesperson Notebook (#110)
  - create new TSP notebook with pulp (#100)
  - [WIP] TSP notebook (#386)
  - [DOC] paths docstring missing (#394)
  - correcting routes doc (#395)
  - [ENH] add back `build` badge (#393)
  - [BUG] Stale links on pysal.org/spaghetti (#387)
  - Rebuild docs (#391)
  - force read-add conn-comp notebook (#390)
  - repushing missing notebooks (#389)
  - Stale links (#388)
  - [ENH] shortest-path extraction (#380)
  - [ENH] regular lattice generator  (#385)
  - [WIP][ENH] addressing shortest path extract (#382)
  - mention the pysal/notebook project (#384)
  - point pattern --> network error message (#383)
  - [ENH] connected components demo notebook (#381)
  - updating README.md (#379)
  - data type testing (#378)
  - spaghetti should handle native cg.Point/Chain objects (#217)
  - Native geometries (#377)
  - adding CoC link to README.md (#376)
  - update CHANGELOG.md format (#375)
  - all reqs found in requirements*.txt necessary? (#346)
  - [ENH] explore overlapping "nearest point" calculation — DRY (#320)
  - altering reference format in docs (#372)
  - Clear instructions for black/pre-commit for contributing (#369)
  - Contrib precommit (#371)
  - alldistances vs. distancematrix? (#351)
  - distance matrix and tree storage (#370)
  - update readme (#367)
  - Adding citations for facility location notebook (#366)
  - v1.4 release checklist (#340)
  - updating README.md (#364)
  - add pre-commit black for PRs? (#333)
  - trying out the black pre-commit hook (#363)
  - adding descartes to environment.yml (#362)
  - Attempt binder3 (#361)
  - need readthedocs.yml? (#360)
  - need all tarball tests? (#359)
  - Attempt binder2 (#358)
  - using environment.yml for binder (#357)
  - Add blob/master/ to notebooks link (#354)
  - addressing #354 (#356)
  - Citation review (#355)
  - launch binder (#78)
  - version 1.3.1 --> 1.4 bump (#353)
  - updating version and docs (#352)
  - improve spaghetti homepage and notebooks? (#332)
  - Review docs for links, etc. (#338)
  - Spelling and default value of `n_processes` (#341)
  - [WIP] TSP notebook (#330)
  - [ENH][WIP]extension of #339: Rahul799 docs/bugfix (#342)

## Pull Requests
  - Fix links 2 (#398)
  - Fix links for notebooks (#397)
  - [WIP] TSP notebook (#386)
  - correcting routes doc (#395)
  - [ENH] add back `build` badge (#393)
  - Rebuild docs (#391)
  - force read-add conn-comp notebook (#390)
  - repushing missing notebooks (#389)
  - Stale links (#388)
  - [WIP][ENH] addressing shortest path extract (#382)
  - mention the pysal/notebook project (#384)
  - point pattern --> network error message (#383)
  - [ENH] connected components demo notebook (#381)
  - updating README.md (#379)
  - data type testing (#378)
  - Native geometries (#377)
  - adding CoC link to README.md (#376)
  - update CHANGELOG.md format (#375)
  - altering reference format in docs (#372)
  - Contrib precommit (#371)
  - distance matrix and tree storage (#370)
  - update readme (#367)
  - Adding citations for facility location notebook (#366)
  - updating README.md (#364)
  - trying out the black pre-commit hook (#363)
  - adding descartes to environment.yml (#362)
  - Attempt binder3 (#361)
  - Attempt binder2 (#358)
  - using environment.yml for binder (#357)
  - addressing #354 (#356)
  - Citation review (#355)
  - version 1.3.1 --> 1.4 bump (#353)
  - updating version and docs (#352)
  - [WIP] TSP notebook (#330)
  - [ENH][WIP]extension of #339: Rahul799 docs/bugfix (#342)

The following individuals contributed to this release:

  - James Gaboardi



-----------------------------------------------------


## Version 1.4.0 (2019-12-31)

We closed a total of 84 issues (enhancements and bug fixes) through 31 pull requests, since our last release on 2019-07-29.

### Issues Closed
  - updating version and docs (#352)
  - improve spaghetti homepage and notebooks? (#332)
  - Review docs for links, etc. (#338)
  - Spelling and default value of `n_processes` (#341)
  - [WIP] TSP notebook (#330)
  - [ENH][WIP]extension of #339: Rahul799 docs/bugfix (#342)
  - Revert "order analysis.py classes/functions alphabetically" (#350)
  - order analysis.py classes/functions alphabetically (#349)
  - updating requirement_dev.txt (#347)
  - update README.md (#348)
  - tarball jobs failing on Travis (#343)
  - updating README.md (#344)
  - links in the docs,reviewed  (#339)
  - automatically generate docstrings for class members (#336)
  - Update docs (#337)
  - Updating .travis.yml (#335)
  - fix indentation in `.travis.yml` (#334)
  - update README.md badges (#331)
  - Citation stipulation for notebooks (#327)
  - Notebooks update part 2 (#329)
  - Notebooks update (#328)
  - update email address in notebooks (#324)
  - Plotting error in Facility_Location.ipynb (#325)
  - Updating Notebooks (#326)
  - module 'pysal.explore.spaghetti' has no attribute 'element_as_gdf' (#323)
  - [ENH] util.compute_length() — DRY (#318)
  - swapping out distance calculation function (#319)
  - adjusting snapping image in README.md (#317)
  - inaccurate documentation — Network.split_arcs() (#315)
  - Split arcs update (#316)
  - streamline badges in README.md (#313)
  - streaming badges on README.md (#314)
  - adding +travis to notification recipients (#312)
  - broken "development guidelines" link (#309)
  - updating broken dev link (#311)
  - Update Travis CI schema (#299)
  - Update travis CI for new testing schema (#308)
  - adding static docs badge (#310)
  - mock c modules for doc dependencies (#288)
  - doi missing from citation (#306)
  - adding Zenodo DOI to README.md and website (#307)
  - blackify setup.py (#305)
  - Change Read the Docs to GitHub? (#301)
  - updating README to reflect GitHub docs (#304)
  - switching to github docs as per #301 (#303)
  - get_versions() function (#302)
  - code formatting with black (#293)
  - blackifying code (#293) (#300)
  - rtree missing libspatialindex_c library file (#294)
  - updating install instructions (addressing #294) (#296)
  - updating install instructions + version bump (#298)
  - updating font for "Warning" (#297)
  - update of install instructions in README.md (#295)

### Pull Requests
  - updating version and docs (#352)
  - [WIP] TSP notebook (#330)
  - [ENH][WIP]extension of #339: Rahul799 docs/bugfix (#342)
  - Revert "order analysis.py classes/functions alphabetically" (#350)
  - order analysis.py classes/functions alphabetically (#349)
  - updating requirement_dev.txt (#347)
  - update README.md (#348)
  - updating README.md (#344)
  - Update docs (#337)
  - Updating .travis.yml (#335)
  - fix indentation in `.travis.yml` (#334)
  - update README.md badges (#331)
  - Notebooks update part 2 (#329)
  - Notebooks update (#328)
  - Updating Notebooks (#326)
  - swapping out distance calculation function (#319)
  - adjusting snapping image in README.md (#317)
  - Split arcs update (#316)
  - streaming badges on README.md (#314)
  - adding +travis to notification recipients (#312)
  - updating broken dev link (#311)
  - Update travis CI for new testing schema (#308)
  - adding static docs badge (#310)
  - adding Zenodo DOI to README.md and website (#307)
  - blackify setup.py (#305)
  - updating README to reflect GitHub docs (#304)
  - switching to github docs as per #301 (#303)
  - blackifying code (#293) (#300)
  - updating install instructions + version bump (#298)
  - updating font for "Warning" (#297)
  - update of install instructions in README.md (#295)

The following individuals contributed to this release:

  - James Gaboardi
  - Rahul799



-----------------------------------------------------


## Version 1.3.1 (2019-07-29)

We closed a total of 21 issues (enhancements and bug fixes) through 7 pull requests, since our last release on 2019-05-21.

### Issues Closed
- updating font for "Warning" (#297)
- update of install instructions in README.md (#295)
- remove geopandas version stipulation (#291)
- updating citation langauge (#290)
- build error beginning (07/01/2019) (#289)
- update css (#287)
- update readthedocs.yml? (#284)
- spaghetti api docs rendering incorrectly (#285)
- docs table left aligned (#286)
- remove extra line in .travis.yml (#283)
- update Changelog (#282)
- Manually updated CHANGELOG following stable release. (#281)
- v1.3 release (#264)
- Bump version 1.3rc2 --> 1.3 (#280)

### Pull Requests
- updating font for "Warning" (#297)
- update of install instructions in README.md (#295)
- updating citation langauge (#290)
- docs table left aligned (#286)
- remove extra line in .travis.yml (#283)
- update Changelog (#282)
- Bump version 1.3rc2 --> 1.3 (#280)

The following individuals contributed to this release:

- James Gaboardi
- Wei Kang

-----------------------------------------------------


## Version 1.3 (2019-05-21)

We closed a total of 14 issues (enhancements and bug fixes) through 5 pull requests, since our last release on 2019-05-14.

### Issues Closed
- Manually updated CHANGELOG following stable release (#281)
- v1.3 release (#264)
- add `requirements_dev.txt` to `MANIFEST.in` (#277)
- Update changelog (#279)
- version bump to include req_dev in MANIFEST.in (#278)
- v1.2 --> 1.3rc1 (for release candidate) (#276)
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)
- update notebooks following prior to v1.3 release (#158)

### Pull Requests
- Update changelog (#279)
- version bump to include req_dev in MANIFEST.in (#278)
- v1.2 --> 1.3rc1 (for release candidate) (#276)
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)

The following individuals contributed to this release:

- James Gaboardi


-----------------------------------------------------


## Version 1.3rc2 (2019-05-14)

We closed a total of 9 issues (enhancements and bug fixes) through 4 pull requests, since our last release on 2019-05-14.

### Issues Closed
- version bump to include req_dev in MANIFEST.in (#278)
- v1.2 --> 1.3rc1 (for release candidate) (#276)
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)
- update notebooks following prior to v1.3 release (#158)

### Pull Requests
- version bump to include req_dev in MANIFEST.in (#278)
- v1.2 --> 1.3rc1 (for release candidate) (#276)
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)

The following individuals contributed to this release:

- James Gaboardi


-----------------------------------------------------


## Version 1.3rc1 (2019-05-14)

We closed a total of 54 issues (enhancements and bug fixes) through 18 pull requests, since our last release on 2019-02-27.

### Issues Closed
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)
- update notebooks following prior to v1.3 release (#158)
- TypeError: '>' not supported between instances of '_NodeCursor' and '_NodeCursor' (#196)
- Update docsite (#273)
- fix docs building (#272)
- docs failing with rtree (#268)
- 3.5 --> 3.7 readthedocs (#269)
- updating README.md (#271)
- conda-forge recipe (#265)
- Solo owner/maintainer (#270)
- update requirements in README (#266)
- updating requirements in README (#267)
- Switch snapping to Rtree package? (#259)
- update python versions in setup.py (#262)
- updating supported python versions in setup.py (#263)
- Drop 3.5, Add 3.7 testing (#260)
- adding support for python3.7 (#261)
- Update Facility_Location.ipynb (#257)
- Further failures in TravisCI builds. (`rake`) (#256)
- bumping down geopandas requirement to 0.3.0 (#255)
- bumping geopandas req version to 0.4.1 (#254)
- TravisCI build failing with `geopandas` (#253)
- Streamline setup travis (#252)
- Remove redundancies in `requirements_xxx.txt` files (#250)
- Removing redundant requirements (#251)
- pandas.core error leading to Travis CI failure (#240)
- uniform .travis.yml (#248)
- switching from pip to conda for reqs install resolves .travis error (#249)
- v1.2.rc1? (#246)
- updating GitHub version badge (#247)
- update version badges (#245)
- AttributeError: module 'spaghetti' has no attribute 'element_as_gdf' (#242)
- bump from rc to stable (#244)
- v1.2rc1 bump (#243)
- adding pandas as a requirement (#241)

### Pull Requests
- Updating notebooks prior to v1.3 release (#275)
- updating README (#274)
- Update docsite (#273)
- fix docs building (#272)
- 3.5 --> 3.7 readthedocs (#269)
- updating README.md (#271)
- updating requirements in README (#267)
- Switch snapping to Rtree package? (#259)
- updating supported python versions in setup.py (#263)
- adding support for python3.7 (#261)
- Update Facility_Location.ipynb (#257)
- bumping down geopandas requirement to 0.3.0 (#255)
- bumping geopandas req version to 0.4.1 (#254)
- Streamline setup travis (#252)
- switching from pip to conda for reqs install resolves .travis error (#249)
- updating GitHub version badge (#247)
- bump from rc to stable (#244)
- v1.2rc1 bump (#243)

The following individuals contributed to this release:

- James Gaboardi
- Wei Kang
- Levi John Wolf
- @Tomgertin


-----------------------------------------------------


## Version 1.2 (2019-02)

This is a stable release of v1.2rc1 with no changes to code.



-----------------------------------------------------

## Version 1.2rc1 (2019-02-27)

We closed a total of 160 issues (enhancements and bug fixes) through 60 pull requests, since our last release on 2018-11-01.

### Issues Closed
- Coverage testing (#239)
- update .travis.yml and introduce .coveragerc similar to pysal/giddy#81 (#238)
- Update `bug` template (#237)
- Update issue templates (#236)
- Add .github directory based on libpysal (#234)
- Adding community info (#235)
- remove README.rst (#223)
- Removing README.rst and updating setup.py (#233)
- pysal/giddy#77 (reference labels) (#231)
- Ref docs (#232)
- Api site doc (#230)
- correction in notebooks/Network_Usage.ipynb (#229)
- edges_to_arcs naming convention (#227)
- altering edges_to_arcs crosswalk name (#228)
- Improve in-line docs -- 24PullRequests for Christmas (#202)
- updating utils.py docs (#226)
- updating all analysis.py docs (#224)
- Docs split arcs (#222)
- Docs allneighbordistances (#221)
- updating docs for full_distance_matrix (#220)
- notes for simulate_observations (#219)
- Docs net funcs (#218)
- bug in snapping points? (#125)
- Deprecation: Container-Based Linux Build Environments (#188)
- Remove sorted edges (#216)
- purpose of class SortedEdges(OrderedDict)? (#90)
- geometry notes in _newpoint_coords (#215)
- count_per_link -- updating docs (#214)
- TravisCI error raise ReadTimeoutError(self._pool, None, 'Read timed out.') (#213)
- variable declaration correction in _snap_to_link (#212)
- compute_distance_to_vertices -- in-line doc improvement (#211)
- improved in-line comments in network.Network.distancebandweights (#210)
- improved in-line comments in network.Network.contiguityweights (#209)
- improved in-line comments in network.Network._docs_evaluate_napts (#208)
- improved in-line comments in network.Network._yield_napts (#207)
- improved in-line comments in network.Network.extractgraph (#206)
- improved in-line comments in network.Network.extract_components (#205)
- improved in-line comments in network.Network._round_sig (#204)
- improved in-line comments in network.Network.__init__ (#203)
- improved in-line comments in _extractnetwork (#201)
- minor spaghetti/util.py doc clean (#200)
- update notebooks following #185 (#187)
- README graphic legend update (#197)
- Update notebooks (#199)
- correcting arc -- arcs attribute (#193)
- attribute declaration error (network.Network.arc) (#192)
- (from pysal.network) Edge ID data structure #933 (#176)
- (from pysal.network) network ring bug #655 (#184)
- Debug of data structure/algo that led to ring/graph errors (#185)
- Creating Network instance from road shapefile fails; ValueError: list.remove(x): x not in list (#9)
- (from pysal.network) Revisit graph weights in network module #496 (#186)
- Updating spaghetti ReadTheDocs (#183)
- tree not recorded in same network arc (#180)
- Nearest tree update (#182)
- clean/create more coherent and uniform variable names (#49)
- Updating/standardizing network/graph element naming (#181)
- Dijkstra maintenance (#179)
- [MAINT] dijkstra (#178)
- Adding .png of snapped point to README.md (#177)
- fixing bug in distancebandweights (#175)
- bug in network.Network.distancebandweights (#174)
- determine necessity of test_distance_band_weights (#62)
- updating ReadTheDocs following #172  (#173)
- Pep8 docs review (#172)
- record connected components (#168)
- [WIP] contiguityweights and connected_components (#171)
- add break condition in contiguityweights() (#170)
- Edge Weighting pysal/pysal #609 (#66)
- Merge unittest scripts (#169)
- Further streamline unittests (#157)
- api docs (#162)
- network element as geodataframe (#143)
- Refactor element as gdf (#167)
- Restructure docs (#166)
- Non responsive docs (#165)
- typo in dijkstra reference (#163)
- Update api docs (#164)
- Update api (#161)
- cleaning up notebooks/Snapping_Demonstration.ipynb (#160)
- Update notebooks (#159)
- add minor test for _round_sig (#152)
- Round sig test (#156)
- updating element_as_gdf.rst (#155)
- Update doc element to gdf (#154)
- Streamline unittests (#147)
- Streamline unittests (#153)
- ENH: element_to_gdf() (#145)
- correcting list comp syntax in _round_sig (#151)
- error in _round_sig() when a coordinate is 0.0 (#150)
- [ENH] streets/network and points need to be in the same CRS/EPSG (#71)
- update markdown docs fromSpaghetti_Pointpatterns_Empirical.ipynb (#146)
- updating typo in notebooks/Spaghetti_Pointpatterns_Empirical.ipynb (#149)
- Minor notebook update (#148)
- update spaghetti info on pysal.site (#144)
- fix RuntimeWarning in analysis.py (#140)
- usage of networkx (#141)
- updating notebooks (#142)
- update spaghetti landing site notebook links (#139)
- rerunning notebooks (#138)
- travis build still failing (#127)

### Pull Requests
- Coverage testing (#239)
- Update `bug` template (#237)
- Update issue templates (#236)
- Adding community info (#235)
- Removing README.rst and updating setup.py (#233)
- Ref docs (#232)
- Api site doc (#230)
- correction in notebooks/Network_Usage.ipynb (#229)
- altering edges_to_arcs crosswalk name (#228)
- updating utils.py docs (#226)
- updating all analysis.py docs (#224)
- Docs split arcs (#222)
- Docs allneighbordistances (#221)
- updating docs for full_distance_matrix (#220)
- notes for simulate_observations (#219)
- Docs net funcs (#218)
- Remove sorted edges (#216)
- geometry notes in _newpoint_coords (#215)
- count_per_link -- updating docs (#214)
- variable declaration correction in _snap_to_link (#212)
- compute_distance_to_vertices -- in-line doc improvement (#211)
- improved in-line comments in network.Network.distancebandweights (#210)
- improved in-line comments in network.Network.contiguityweights (#209)
- improved in-line comments in network.Network._docs_evaluate_napts (#208)
- improved in-line comments in network.Network._yield_napts (#207)
- improved in-line comments in network.Network.extractgraph (#206)
- improved in-line comments in network.Network.extract_components (#205)
- improved in-line comments in network.Network._round_sig (#204)
- improved in-line comments in network.Network.__init__ (#203)
- improved in-line comments in _extractnetwork (#201)
- minor spaghetti/util.py doc clean (#200)
- Update notebooks (#199)
- correcting arc -- arcs attribute (#193)
- Debug of data structure/algo that led to ring/graph errors (#185)
- Updating spaghetti ReadTheDocs (#183)
- Nearest tree update (#182)
- Updating/standardizing network/graph element naming (#181)
- Dijkstra maintenance (#179)
- Adding .png of snapped point to README.md (#177)
- fixing bug in distancebandweights (#175)
- updating ReadTheDocs following #172  (#173)
- Pep8 docs review (#172)
- [WIP] contiguityweights and connected_components (#171)
- Merge unittest scripts (#169)
- Refactor element as gdf (#167)
- Restructure docs (#166)
- Non responsive docs (#165)
- Update api docs (#164)
- Update api (#161)
- cleaning up notebooks/Snapping_Demonstration.ipynb (#160)
- Update notebooks (#159)
- Round sig test (#156)
- updating element_as_gdf.rst (#155)
- Update doc element to gdf (#154)
- Streamline unittests (#153)
- ENH: element_to_gdf() (#145)
- correcting list comp syntax in _round_sig (#151)
- updating typo in notebooks/Spaghetti_Pointpatterns_Empirical.ipynb (#149)
- updating notebooks (#142)
- rerunning notebooks (#138)

The following individuals contributed to this release:

- James Gaboardi

-----------------------------------------------------


## Version 1.1.1 (2018-10-31)

We closed a total of 5 issues (enhancements and bug fixes) through 2 pull requests, since our last release on 2018-10-30.

### Issues Closed
- removed .txt format CHANGELOG (#129)
- rel: v1.1.0 -- Adjusting CHANGELOG.md prior to tagged release (#128)
- prepare new release for pypi -- v1.1.0 (#57)

### Pull Requests
- removed .txt format CHANGELOG (#129)
- rel: v1.1.0 -- Adjusting CHANGELOG.md prior to tagged release (#128)

The following individuals contributed to this release:

- James Gaboardi

-----------------------------------------------------


## Version 1.1.0 (2018-10-30)

We closed a total of 82 issues (enhancements and bug fixes) through 25 pull requests, since our last release on 2018-08-10.

### Issues Closed
  - prepare new release for pypi -- v1.1.0 (#57)
  - refreshing documentation (#124)
  - option to add distance from point to snapped location (#75)
  - attempting pyproj_fix (#122)
  - [WIP] Add snap dist (#123)
  - travis CI build failing with `KeyError: 'PROJ_LIB'` (#121)
  - resolving obs_to_node question (#120)
  - why convert obs_to_node from defaultdict to list? (#93)
  - network.PointPatterns condense code chunk (#74)
  - condensing idvariable code chunk (#119)
  - Network Cross Nearest Neighbor (#102)
  - refreshing docs (#117)
  - shortest path look up from allneighborsdistances? (#115)
  - adding shortest path traceback for point patterns (#116)
  - ImportError: No module named 'boto3' (#113)
  - adding boto3 test req for current fiona bug (#114)
  - [WIP] cleanup_nearest_neighbor (#112)
  - duplicate neighbor distance functions? (#91)
  - network.allneighbordistances documentation not accurate (#111)
  - [WIP] General package maintenance (#109)
  - new badges (#96)
  - tools/ (#99)
  - updating thumbnails in docs (#108)
  - [WIP] updating docs, badges, tools, etc. (#107)
  - initializing new sphinx docs based on submodule_template (#98)
  - new labels for issues (#105)
  - populating sphinx docs (#37)
  - tests for analysis and util (#44)
  - NetworkF (#94)
  - rename functions to be more pythonic (#104)
  - add poisson distribution to tests (#106)
  - initial sphix docs attempt (#67)
  - bumping version to 1.1.0 (#97)
  - adding in new tests for utils.py (#95)
  - add flag for util.generatetree() (#92)
  - [completed atm] - docstrings cleanup (#89)
  - clean docstrings (#77)
  - adding MANIFEST.in (#88)
  - clearing Facility_Location.ipynb (#87)
  - removing typo in Facility_Location (#86)
  - clearing Facility_Location.ipynb (#85)
  - updating Facility_Location.ipynb for typos (#84)
  - adding Facility_Location.ipynb (#83)
  - new notebook ideas (#48)
  - adding windows functionality for 'last updated' (#82)
  - ensure nearest nodes are returned as np.array() (#73)
  - snapping trouble when the initial node in KDtree is the nearest (#72)
  - add Github version badge (#80)
  - add open issues badge (#79)
  - update notebooks as per pysal/pysal#1057 (#81)
  - [Complete/Needs Review] updating `in_shp` parameter in spaghetti.Network (#69)
  - [ENH] geopandas.GeoDataFrame for PointPattern (#28)
  - update in_shp kwarg in spaghetti.Network (#68)
  - removing undeclared edge_time attribute (#65)
  - update README.txt (#33)
  - [ENH] Add badges (#31)
  - Publish on Zenodo (#36)

### Pull Requests
  - refreshing documentation (#124)
  - attempting pyproj_fix (#122)
  - [WIP] Add snap dist (#123)
  - resolving obs_to_node question (#120)
  - condensing idvariable code chunk (#119)
  - refreshing docs (#117)
  - adding shortest path traceback for point patterns (#116)
  - [WIP] cleanup_nearest_neighbor (#112)
  - [WIP] General package maintenance (#109)
  - updating thumbnails in docs (#108)
  - [WIP] updating docs, badges, tools, etc. (#107)
  - initializing new sphinx docs based on submodule_template (#98)
  - bumping version to 1.1.0 (#97)
  - adding in new tests for utils.py (#95)
  - [completed atm] - docstrings cleanup (#89)
  - adding MANIFEST.in (#88)
  - clearing Facility_Location.ipynb (#87)
  - removing typo in Facility_Location (#86)
  - clearing Facility_Location.ipynb (#85)
  - updating Facility_Location.ipynb for typos (#84)
  - adding Facility_Location.ipynb (#83)
  - adding windows functionality for 'last updated' (#82)
  - ensure nearest nodes are returned as np.array() (#73)
  - [Complete/Needs Review] updating `in_shp` parameter in spaghetti.Network (#69)
  - removing undeclared edge_time attribute (#65)

The following individuals contributed to this release:

  - James Gaboardi


--------------------------------------------------------------


## GitHub Stats for 2017/03/15 - 2018/07/28 (tag: None)

These lists are automatically generated,and may be incomplete or contain duplicates.


We closed a total of 39 issues, 12 pull requests and 27 regular issues;
 this is the full list (generated with the script 
:file:`tools/github_stats.py`):

### Pull Requests (12):

* `#25`: preparing for pypi release
* `#23`: Py2topy3
* `#24`: Spaghetti/update travis
* `#16`: adding an api.py file to spaghetti
* `#17`: Spag/analysis cosmetics
* `#14`: removing `math` in favor of `numpy` for calcs
* `#13`: minor doc commit to practice git workflow
* `#11`: adding a license
* `#10`: setting up travis ci
* `#8`: the first of the new network tutorial notebooks for pysal/spaghetti
* `#7`: rename makes geonet redundant
* `#6`: updated package name and short description in __init__

### Issues (27):

* `#5`: update import scheme for new package name
* `#26`: Prepare a release of spaghetti for pypi
* `#32`: pip
* `#25`: preparing for pypi release
* `#19`: api.py tests
* `#29`: trailing comma not allowed with surrounding parenthesis
* `#27`: Necessity of __future__?
* `#21`: `spaghetti` currently only python 2.7.x compatible
* `#22`: Geopandas read
* `#23`: Py2topy3
* `#24`: Spaghetti/update travis
* `#20`: Generalize the Network input API for libpysal/#59
* `#18`: adding gitter badge to README.md
* `#15`: spaghetti needs an api.py module
* `#17`: Spag/analysis cosmetics
* `#16`: adding an api.py file to spaghetti
* `#4`: test release and setup.py
* `#3`: add a readme
* `#14`: removing `math` in favor of `numpy` for calcs
* `#13`: minor doc commit to practice git workflow
* `#12`: Pp notebook
* `#11`: adding a license
* `#2`: set up testing for travis
* `#10`: setting up travis ci
* `#8`: the first of the new network tutorial notebooks for pysal/spaghetti
* `#7`: rename makes geonet redundant
* `#6`: updated package name and short description in __init__
